@@ -7,21 +7,15 @@
 #include "../kwalletmanager_version.h"
 #include "konfigurator.h"
 
-#include <kauth_version.h>
-#include <KPluginFactory>
-#include <QInputDialog>
-#include <KWallet>
-#if KAUTH_VERSION >= QT_VERSION_CHECK(5, 92, 0)
 #include <KAuth/Action>
 #include <KAuth/ActionReply>
 #include <KAuth/ExecuteJob>
-#else
-#include <KAuthAction>
-#include <KAuthActionReply>
-#include <KAuthExecuteJob>
-#endif
 #include <KConfigGroup>
 #include <KMessageBox>
+#include <KPluginFactory>
+#include <KWallet>
+#include <QInputDialog>
+#include <kauth_version.h>
 
 #include <KAboutData>
 
@@ -38,11 +32,12 @@
 
 #define KWALLETMANAGERINTERFACE "org.kde.KWallet"
 
-K_PLUGIN_FACTORY(KWalletFactory, registerPlugin<KWalletConfig>();)
+K_PLUGIN_CLASS_WITH_JSON(KWalletConfig, "kwalletconfig.json")
 
 KWalletConfig::KWalletConfig(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args),
-      _cfg(KSharedConfig::openConfig(QStringLiteral("kwalletrc"), KConfig::NoGlobals))
+    : KCModule(parent, args)
+      , _wcw(new WalletConfigWidget(this))
+      , _cfg(KSharedConfig::openConfig(QStringLiteral("kwalletrc"), KConfig::NoGlobals))
 {
     auto about = new KAboutData(QStringLiteral("kcmkwallet5"),
                                        i18n("KDE Wallet Control Module"),
@@ -58,7 +53,6 @@ KWalletConfig::KWalletConfig(QWidget *parent, const QVariantList &args)
 
     auto vbox = new QVBoxLayout(this);
     vbox->setContentsMargins(0, 0, 0, 0);
-    _wcw = new WalletConfigWidget(this);
     vbox->addWidget(_wcw);
 
     connect(_wcw->_enabled, &QCheckBox::clicked, this, &KWalletConfig::configChanged);
@@ -379,7 +373,11 @@ void KWalletConfig::customContextMenuRequested(const QPoint &pos)
     if (item && item->parent()) {
         auto m = new QMenu(this);
         m->setTitle(item->parent()->text(0));
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         m->addAction(i18n("&Delete"), this, &KWalletConfig::deleteEntry, Qt::Key_Delete);
+#else
+        m->addAction(i18n("&Delete"), Qt::Key_Delete, this, &KWalletConfig::deleteEntry);
+#endif
         m->exec(_wcw->_accessList->mapToGlobal(pos));
         delete m;
     }
